@@ -7,8 +7,12 @@ import semver
 from kacl.config import KACLConfig
 from kacl.element import KACLElement
 from kacl.exception import KACLException
+from kacl.jira_client import KACLJiraClient
 from kacl.link_provider import LinkProvider
 from kacl.parser import KACLParser
+from kacl.utils import convert_markdown_to_jira
+from kacl.utils import extract_issue_ids
+from kacl.utils import replace_env_variables
 from kacl.validation import KACLValidation
 from kacl.version import KACLVersion
 
@@ -23,6 +27,7 @@ class KACLDocument:
         headers=None,
         versions=None,
         link_references=None,
+        meta_data=None,
         config=KACLConfig(),
     ):
         self.__data = data
@@ -31,6 +36,7 @@ class KACLDocument:
         self.__link_references = link_references
         if not self.__link_references:
             self.__link_references = dict()
+        self.__meta_data = meta_data
         self.config = config
 
     def validate(self):
@@ -361,7 +367,7 @@ class KACLDocument:
                             link_provider.initial_version(**fargs)
                         )
 
-    def get(self, version):
+    def get(self, version) -> KACLVersion:
         """Returns the selected version
 
         Arguments:
@@ -462,6 +468,74 @@ class KACLDocument:
             else:
                 versions[0].set_link(link_provider.initial_version(**fargs))
 
+    def get_associated_issues(self, version=None):
+        """returns all issues for the given version"""
+        kacl_version = None
+        if not version:
+            # if no version is given, we will use the current version
+            kacl_version = self.get(self.current_version())
+        else:
+            kacl_version = self.get(version)
+
+        patterns = {"jira": self.config.issue_tracker_jira_issue_patterns}
+
+        # get all issue ids
+        return extract_issue_ids(kacl_version, patterns)
+
+    def render_comments(self, version=None) -> dict[str:str]:
+        if version is None:
+            version = self.current_version()
+
+        changes = self.get(version)
+        link_provider = self.__get_link_provider()
+
+        format_string = {
+            "new_version": version,
+            "changes": changes.body(),
+            "link": link_provider.version_link(version),
+        }
+
+        comments = {}
+
+        if self.config.issue_tracker_jira_comment_template:
+            jira_comment = replace_env_variables(
+                self.config.issue_tracker_jira_comment_template
+            )
+            jira_comment = jira_comment.format(**format_string)
+            jira_comment = convert_markdown_to_jira(jira_comment)
+            comments["jira"] = jira_comment
+
+        return comments
+
+    def add_comments(self, version=None) -> dict[str : dict[str:bool]]:
+        # This function will parse all versions for known issue ids and search the defined
+        # issue tracking system for the issue. If the issue is found, a comment will be added to the
+        # issue with the changelog/release information
+
+        issue_ids = self.get_associated_issues(version)
+
+        jira_client = None
+        if "jira" in issue_ids and len(issue_ids["jira"]) > 0:
+            client = KACLJiraClient(self.config)
+            if client.is_authenticated():
+                jira_client = client
+
+        rendered_comments = self.render_comments(version)
+
+        report = {"jira": {}}
+
+        if jira_client:
+            # comment on jira tickets
+            for jira_issue in issue_ids["jira"]:
+                try:
+                    jira_client.add_comment(jira_issue, rendered_comments["jira"])
+                    report["jira"][jira_issue] = True
+                except Exception:
+                    report["jira"][jira_issue] = False
+                    continue
+
+        return report
+
     def header(self):
         """Gives access to the top level heading element
 
@@ -489,6 +563,14 @@ class KACLDocument:
         """
         return self.__versions
 
+    def metadata(self):
+        """Returns the metadata as dict or None if not available
+
+        Returns:
+            [dict|None] -- metadata of the document
+        """
+        return self.__meta_data
+
     @staticmethod
     def init():
         return KACLDocument.parse(
@@ -519,6 +601,8 @@ The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
             data_lf
         )
 
+        meta_data = KACLParser.parse_metadata(data_lf)
+
         changelog_body = data_lf
         if link_reference_begin:
             changelog_body = data_lf[:link_reference_begin]
@@ -539,6 +623,7 @@ The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
             headers=headers,
             versions=versions,
             link_references=link_references,
+            meta_data=meta_data,
         )
 
     def __get_link_provider(
@@ -580,6 +665,8 @@ The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
                         "ERROR: Could not determine project url. Update your config or run within a valid git repository"
                     )
 
+        host_url = host_url.removesuffix(".git")
+
         return LinkProvider(
             host_url=host_url,
             compare_versions_template=compare_versions_template,
