@@ -2,6 +2,7 @@ import json
 import os
 import shutil
 
+import pytest
 from click.testing import CliRunner
 from freezegun import freeze_time
 
@@ -375,3 +376,117 @@ def test_squash_current(tmp_path, snapshot):
         )
         assert result.exit_code == 0, result.output
         snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
+
+
+@pytest.mark.skip(reason="No issue tracker openly available, test locally.")
+def test_add_comments(tmp_path):
+    runner = CliRunner()
+    root_dir = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)),
+        "..",
+    )
+    resources_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data/")
+    changelog_file = os.path.join(resources_dir, "CHANGELOG_issue_management.md")
+
+    with runner.isolated_filesystem(temp_dir=tmp_path) as project_root_path:
+        shutil.copyfile(changelog_file, os.path.join(project_root_path, "CHANGELOG.md"))
+        shutil.copytree(
+            os.path.join(root_dir, ".git"), os.path.join(project_root_path, ".git")
+        )
+        result = runner.invoke(
+            cli,
+            [
+                "-f",
+                "CHANGELOG.md",
+                "add-comments",
+                "1.0.0",
+                "--jira-username",
+                os.getenv("JIRA_USERNAME"),
+                "--jira-password",
+                os.getenv("JIRA_PASSWORD"),
+                "--jira-host",
+                os.getenv("JIRA_HOST"),
+                "--jira-issue-pattern",
+                "JIRA-[0-9]+",
+                "--jira-issue-pattern",
+                "MYJIRA-[0-9]+",
+                "--jira-issue-pattern",
+                "[A-Z]+-[0-9]+",
+            ],
+            catch_exceptions=False,
+        )
+        assert result.exit_code == 0, result.output
+
+
+@freeze_time("2023-01-01")
+def test_get_no_link_available(tmp_path, snapshot):
+    runner = CliRunner()
+    resources_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data/")
+    changelog_file = os.path.join(resources_dir, "CHANGELOG_missing_link.md")
+
+    with runner.isolated_filesystem(temp_dir=tmp_path) as project_root_path:
+        result = runner.invoke(
+            cli,
+            [
+                "-c",
+                os.path.join(resources_dir, "extension-config.yml"),
+                "-f",
+                changelog_file,
+                "get",
+                "2.0.0",
+            ],
+            catch_exceptions=False,
+        )
+        assert result.exit_code == 0, result.output
+        with open(os.path.join(project_root_path, "output.md"), "w") as file:
+            file.write(result.output)
+        snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
+
+
+def test_get_link_available(tmp_path, snapshot):
+    runner = CliRunner()
+    resources_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data/")
+    changelog_file = os.path.join(resources_dir, "CHANGELOG_missing_link.md")
+
+    with runner.isolated_filesystem(temp_dir=tmp_path) as project_root_path:
+        result = runner.invoke(
+            cli,
+            [
+                "-c",
+                os.path.join(resources_dir, "extension-config.yml"),
+                "-f",
+                changelog_file,
+                "get",
+                "1.0.0",
+            ],
+            catch_exceptions=False,
+        )
+        assert result.exit_code == 0, result.output
+        with open(os.path.join(project_root_path, "output.md"), "w") as file:
+            file.write(result.output)
+        snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
+
+
+def test_get_suppress_available_link(tmp_path, snapshot):
+    runner = CliRunner()
+    resources_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data/")
+    changelog_file = os.path.join(resources_dir, "CHANGELOG_missing_link.md")
+
+    with runner.isolated_filesystem(temp_dir=tmp_path) as project_root_path:
+        result = runner.invoke(
+            cli,
+            [
+                "-c",
+                os.path.join(resources_dir, "extension-config.yml"),
+                "-f",
+                changelog_file,
+                "get",
+                "--no-link",
+                "1.0.0",
+            ],
+            catch_exceptions=False,
+        )
+        assert result.exit_code == 0, result.output
+        with open(os.path.join(project_root_path, "output.md"), "w") as file:
+            file.write(result.output)
+        snapshot_directory(snapshot=snapshot, directory_path=project_root_path)
